Programming Model
=================

The approach to writing code in HGraph is different to most traditional programming models
and requires a different mindset. This section attempts to describe the metal model and
approach to making the most out of the HGraph framework.

.. toctree::
    mental_model
    code_organisation

